[cairo-commit] libpixman/src ic.c, 1.21, 1.22 icblt.c, 1.6, 1.7 icbltone.c, 1.7, 1.8 iccompose.c, 1.18, 1.19 icimage.c, 1.28, 1.29 icstipple.c, 1.5, 1.6

Jeff Muizelaar commit at pdx.freedesktop.org
Thu Jun 23 19:35:47 PDT 2005


Committed by: jrmuizel

Update of /cvs/cairo/libpixman/src
In directory gabe:/tmp/cvs-serv22510/src

Modified Files:
	ic.c icblt.c icbltone.c iccompose.c icimage.c icstipple.c 
Log Message:
2005-06-23  Jeff Muizelaar  <jeff at infidigm.net>

	* src/ic.c: (pixman_compositeSrcAdd_1000x1000),
	(pixman_compositeSolidMask_nx1xn):
	* src/icblt.c: (IcBlt), (IcBlt24Line), (IcBlt24), (IcBltOdd),
	(IcBltOdd24), (IcSetBltOdd), (IcBltStip):
	* src/icbltone.c: (IcBltOne), (IcBltOne24):
	* src/iccompose.c: (IcFetch_a8r8g8b8), (IcFetch_x8r8g8b8),
	(IcFetch_a8b8g8r8), (IcFetch_x8b8g8r8), (IcFetch_r8g8b8),
	(IcFetch_b8g8r8), (IcFetch_r5g6b5), (IcFetch_b5g6r5),
	(IcFetch_a1r5g5b5), (IcFetch_x1r5g5b5), (IcFetch_a1b5g5r5),
	(IcFetch_x1b5g5r5), (IcFetch_a4r4g4b4), (IcFetch_x4r4g4b4),
	(IcFetch_a4b4g4r4), (IcFetch_x4b4g4r4), (IcFetch_a8),
	(IcFetcha_a8), (IcFetch_r3g3b2), (IcFetch_b2g3r3),
	(IcFetch_a2r2g2b2), (IcFetch_a4), (IcFetcha_a4), (IcFetch_r1g2b1),
	(IcFetch_b1g2r1), (IcFetch_a1r1g1b1), (IcFetch_a1b1g1r1),
	(IcFetcha_a1), (IcFetch_a1), (IcStore_a8r8g8b8),
	(IcStore_x8r8g8b8), (IcStore_a8b8g8r8), (IcStore_x8b8g8r8),
	(IcStore_r8g8b8), (IcStore_b8g8r8), (IcStore_r5g6b5),
	(IcStore_b5g6r5), (IcStore_a1r5g5b5), (IcStore_x1r5g5b5),
	(IcStore_a1b5g5r5), (IcStore_x1b5g5r5), (IcStore_a4r4g4b4),
	(IcStore_x4r4g4b4), (IcStore_a4b4g4r4), (IcStore_x4b4g4r4),
	(IcStore_a8), (IcStore_r3g3b2), (IcStore_b2g3r3),
	(IcStore_a2r2g2b2), (IcStore_a4), (IcStore_r1g2b1),
	(IcStore_b1g2r1), (IcStore_a1r1g1b1), (IcStore_a1b1g1r1),
	(IcStore_a1), (IcBuildCompositeOperand):
	* src/icimage.c: (pixman_image_create_for_data):
	* src/icstipple.c: (IcTransparentSpan):

	s/pixman_bits_t/FbBits/s


Index: ic.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/ic.c,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- ic.c	24 Jun 2005 02:33:34 -0000	1.21
+++ ic.c	24 Jun 2005 02:35:45 -0000	1.22
@@ -21,7 +21,7 @@
  * Author:  Keith Packard, SuSE, Inc.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 #define cvt8888to0565(s)    ((((s) >> 3) & 0x001f) | \
 			     (((s) >> 5) & 0x07e0) | \
@@ -92,7 +92,7 @@
 }
 
 #define IcComposeGetSolid(image, bits) { \
-    pixman_bits_t	*__bits__; \
+    FbBits	*__bits__; \
     IcStride	__stride__; \
     int		__bpp__; \
     int		__xoff__,__yoff__; \
@@ -118,13 +118,13 @@
 }
 
 #define IcComposeGetStart(image,x,y,type,stride,line,mul) {\
-    pixman_bits_t	*__bits__; \
+    FbBits	*__bits__; \
     IcStride	__stride__; \
     int		__bpp__; \
     int		__xoff__,__yoff__; \
 \
     IcGetPixels((image)->pixels,__bits__,__stride__,__bpp__,__xoff__,__yoff__); \
-    (stride) = __stride__ * sizeof (pixman_bits_t) / sizeof (type); \
+    (stride) = __stride__ * sizeof (FbBits) / sizeof (type); \
     (line) = ((type *) __bits__) + (stride) * ((y) - __yoff__) + (mul) * ((x) - __xoff__); \
 }
 
@@ -767,7 +767,7 @@
 			     uint16_t     width,
 			     uint16_t     height)
 {
-    pixman_bits_t	*dstBits, *srcBits;
+    FbBits	*dstBits, *srcBits;
     IcStride	dstStride, srcStride;
     int		dstBpp, srcBpp;
     int		dstXoff, dstYoff;
@@ -810,13 +810,13 @@
 			    uint16_t     width,
 			    uint16_t     height)
 {
-    pixman_bits_t	*dstBits;
+    FbBits	*dstBits;
     IcStip	*maskBits;
     IcStride	dstStride, maskStride;
     int		dstBpp, maskBpp;
     int		dstXoff, dstYoff;
     int		maskXoff, maskYoff;
-    pixman_bits_t	src;
+    FbBits	src;
     
     IcComposeGetSolid(iSrc, src);
 

Index: iccompose.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/iccompose.c,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -d -r1.18 -r1.19
--- iccompose.c	26 May 2005 20:02:31 -0000	1.18
+++ iccompose.c	24 Jun 2005 02:35:45 -0000	1.19
@@ -21,7 +21,7 @@
  */
 
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 /*
  * General purpose compositing code optimized for minimal memory
@@ -1514,21 +1514,21 @@
 static uint32_t
 IcFetch_a8r8g8b8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     return ((uint32_t *)line)[offset >> 5];
 }
 
 static uint32_t
 IcFetch_x8r8g8b8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     return ((uint32_t *)line)[offset >> 5] | 0xff000000;
 }
 
 static uint32_t
 IcFetch_a8b8g8r8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint32_t *)line)[offset >> 5];
 
     return ((pixel & 0xff000000) |
@@ -1540,7 +1540,7 @@
 static uint32_t
 IcFetch_x8b8g8r8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint32_t *)line)[offset >> 5];
 
     return ((0xff000000) |
@@ -1552,7 +1552,7 @@
 static uint32_t
 IcFetch_r8g8b8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
 #if IMAGE_BYTE_ORDER == MSBFirst
     return (0xff000000 |
@@ -1570,7 +1570,7 @@
 static uint32_t
 IcFetch_b8g8r8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
 #if IMAGE_BYTE_ORDER == MSBFirst
     return (0xff000000 |
@@ -1588,7 +1588,7 @@
 static uint32_t
 IcFetch_r5g6b5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1601,7 +1601,7 @@
 static uint32_t
 IcFetch_b5g6r5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1614,7 +1614,7 @@
 static uint32_t
 IcFetch_a1r5g5b5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  a,r,g,b;
 
@@ -1628,7 +1628,7 @@
 static uint32_t
 IcFetch_x1r5g5b5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1641,7 +1641,7 @@
 static uint32_t
 IcFetch_a1b5g5r5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  a,r,g,b;
 
@@ -1655,7 +1655,7 @@
 static uint32_t
 IcFetch_x1b5g5r5 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1668,7 +1668,7 @@
 static uint32_t
 IcFetch_a4r4g4b4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  a,r,g,b;
 
@@ -1682,7 +1682,7 @@
 static uint32_t
 IcFetch_x4r4g4b4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1695,7 +1695,7 @@
 static uint32_t
 IcFetch_a4b4g4r4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  a,r,g,b;
 
@@ -1709,7 +1709,7 @@
 static uint32_t
 IcFetch_x4b4g4r4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint16_t *) line)[offset >> 4];
     uint32_t  r,g,b;
 
@@ -1722,7 +1722,7 @@
 static uint32_t
 IcFetch_a8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t   pixel = ((uint8_t *) line)[offset>>3];
     
     return pixel << 24;
@@ -1731,7 +1731,7 @@
 static uint32_t
 IcFetcha_a8 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t   pixel = ((uint8_t *) line)[offset>>3];
     
     pixel |= pixel << 8;
@@ -1742,7 +1742,7 @@
 static uint32_t
 IcFetch_r3g3b2 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t   pixel = ((uint8_t *) line)[offset>>3];
     uint32_t  r,g,b;
     
@@ -1758,7 +1758,7 @@
 static uint32_t
 IcFetch_b2g3r3 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t   pixel = ((uint8_t *) line)[offset>>3];
     uint32_t  r,g,b;
     
@@ -1776,7 +1776,7 @@
 static uint32_t
 IcFetch_a2r2g2b2 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t   pixel = ((uint8_t *) line)[offset>>3];
     uint32_t   a,r,g,b;
 
@@ -1797,7 +1797,7 @@
 static uint32_t
 IcFetch_a4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     
     pixel |= pixel << 4;
@@ -1807,7 +1807,7 @@
 static uint32_t
 IcFetcha_a4 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     
     pixel |= pixel << 4;
@@ -1819,7 +1819,7 @@
 static uint32_t
 IcFetch_r1g2b1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     uint32_t  r,g,b;
 
@@ -1832,7 +1832,7 @@
 static uint32_t
 IcFetch_b1g2r1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     uint32_t  r,g,b;
 
@@ -1845,7 +1845,7 @@
 static uint32_t
 IcFetch_a1r1g1b1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     uint32_t  a,r,g,b;
 
@@ -1859,7 +1859,7 @@
 static uint32_t
 IcFetch_a1b1g1r1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = Fetch4(line, offset);
     uint32_t  a,r,g,b;
 
@@ -1873,7 +1873,7 @@
 static uint32_t
 IcFetcha_a1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint32_t *)line)[offset >> 5];
     uint32_t  a;
 #if BITMAP_BIT_ORDER == MSBFirst
@@ -1893,7 +1893,7 @@
 static uint32_t
 IcFetch_a1 (pixman_compositeOperand *op)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel = ((uint32_t *)line)[offset >> 5];
     uint32_t  a;
 #if BITMAP_BIT_ORDER == MSBFirst
@@ -1918,21 +1918,21 @@
 static void
 IcStore_a8r8g8b8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     ((uint32_t *)line)[offset >> 5] = value;
 }
 
 static void
 IcStore_x8r8g8b8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     ((uint32_t *)line)[offset >> 5] = value & 0xffffff;
 }
 
 static void
 IcStore_a8b8g8r8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     Splita(value);
     ((uint32_t *)line)[offset >> 5] = a << 24 | b << 16 | g << 8 | r;
 }
@@ -1940,7 +1940,7 @@
 static void
 IcStore_x8b8g8r8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     Split(value);
     ((uint32_t *)line)[offset >> 5] = b << 16 | g << 8 | r;
 }
@@ -1948,7 +1948,7 @@
 static void
 IcStore_r8g8b8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     Split(value);
 #if IMAGE_BYTE_ORDER == MSBFirst
@@ -1965,7 +1965,7 @@
 static void
 IcStore_b8g8r8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     Split(value);
 #if IMAGE_BYTE_ORDER == MSBFirst
@@ -1982,7 +1982,7 @@
 static void
 IcStore_r5g6b5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((r << 8) & 0xf800) |
@@ -1993,7 +1993,7 @@
 static void
 IcStore_b5g6r5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((b << 8) & 0xf800) |
@@ -2004,7 +2004,7 @@
 static void
 IcStore_a1r5g5b5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Splita(value);
     *pixel = (((a << 8) & 0x8000) |
@@ -2016,7 +2016,7 @@
 static void
 IcStore_x1r5g5b5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((r << 7) & 0x7c00) |
@@ -2027,7 +2027,7 @@
 static void
 IcStore_a1b5g5r5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Splita(value);
     *pixel = (((a << 8) & 0x8000) |
@@ -2039,7 +2039,7 @@
 static void
 IcStore_x1b5g5r5 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((b << 7) & 0x7c00) |
@@ -2050,7 +2050,7 @@
 static void
 IcStore_a4r4g4b4 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Splita(value);
     *pixel = (((a << 8) & 0xf000) |
@@ -2062,7 +2062,7 @@
 static void
 IcStore_x4r4g4b4 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((r << 4) & 0x0f00) |
@@ -2073,7 +2073,7 @@
 static void
 IcStore_a4b4g4r4 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Splita(value);
     *pixel = (((a << 8) & 0xf000) |
@@ -2085,7 +2085,7 @@
 static void
 IcStore_x4b4g4r4 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint16_t  *pixel = ((uint16_t *) line) + (offset >> 4);
     Split(value);
     *pixel = (((b << 4) & 0x0f00) |
@@ -2096,7 +2096,7 @@
 static void
 IcStore_a8 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     *pixel = value >> 24;
 }
@@ -2104,7 +2104,7 @@
 static void
 IcStore_r3g3b2 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     Split(value);
     *pixel = (((r     ) & 0xe0) |
@@ -2115,7 +2115,7 @@
 static void
 IcStore_b2g3r3 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     Split(value);
     *pixel = (((b     ) & 0xe0) |
@@ -2126,7 +2126,7 @@
 static void
 IcStore_a2r2g2b2 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint8_t   *pixel = ((uint8_t *) line) + (offset >> 3);
     Splita(value);
     *pixel = (((a     ) & 0xc0) |
@@ -2149,14 +2149,14 @@
 static void
 IcStore_a4 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     Store4(line,offset,value>>28);
 }
 
 static void
 IcStore_r1g2b1 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel;
     
     Split(value);
@@ -2169,7 +2169,7 @@
 static void
 IcStore_b1g2r1 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel;
     
     Split(value);
@@ -2182,7 +2182,7 @@
 static void
 IcStore_a1r1g1b1 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel;
     Splita(value);
     pixel = (((a >> 4) & 0x8) |
@@ -2195,7 +2195,7 @@
 static void
 IcStore_a1b1g1r1 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  pixel;
     Splita(value);
     pixel = (((a >> 4) & 0x8) |
@@ -2208,7 +2208,7 @@
 static void
 IcStore_a1 (pixman_compositeOperand *op, uint32_t value)
 {
-    pixman_bits_t  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
+    FbBits  *line = op->u.drawable.line; uint32_t offset = op->u.drawable.offset;
     uint32_t  *pixel = ((uint32_t *) line) + (offset >> 5);
     uint32_t  mask = IcStipMask(offset & 0x1f, 1);
 
@@ -2618,7 +2618,7 @@
 	for (i = 0; i < NumAccessMap; i++)
 	    if (icAccessMap[i].format_code == image->format_code)
 	    {
-		pixman_bits_t	*bits;
+		FbBits	*bits;
 		IcStride	stride;
 		int		bpp;
 

Index: icimage.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icimage.c,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -d -r1.28 -r1.29
--- icimage.c	26 May 2005 20:02:31 -0000	1.28
+++ icimage.c	24 Jun 2005 02:35:45 -0000	1.29
@@ -21,7 +21,7 @@
  * Author:  Keith Packard, SuSE, Inc.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 pixman_image_t *
 pixman_image_create (pixman_format_t	*format,
@@ -48,7 +48,7 @@
 slim_hidden_def(pixman_image_create);
 
 pixman_image_t *
-pixman_image_create_for_data (pixman_bits_t *data, pixman_format_t *format, int width, int height, int bpp, int stride)
+pixman_image_create_for_data (FbBits *data, pixman_format_t *format, int width, int height, int bpp, int stride)
 {
     pixman_image_t	*image;
     IcPixels	*pixels;
@@ -245,7 +245,7 @@
     return &image->image_format;
 }
 
-pixman_bits_t *
+FbBits *
 pixman_image_get_data (pixman_image_t	*image)
 {
     return image->pixels->data;

Index: icstipple.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icstipple.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- icstipple.c	2 Mar 2005 15:43:33 -0000	1.5
+++ icstipple.c	24 Jun 2005 02:35:45 -0000	1.6
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 #ifndef ICNOPIXADDR
 /*
@@ -55,9 +55,9 @@
  */
 
 void
-IcTransparentSpan (pixman_bits_t   *dst,
-		   pixman_bits_t   stip,
-		   pixman_bits_t   fgxor,
+IcTransparentSpan (FbBits   *dst,
+		   FbBits   stip,
+		   FbBits   fgxor,
 		   int	    n)
 {
     IcStip  s;




More information about the cairo-commit mailing list
Index: icblt.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icblt.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- icblt.c	24 Jun 2005 02:30:20 -0000	1.6
+++ icblt.c	24 Jun 2005 02:35:45 -0000	1.7
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 #define InitializeShifts(sx,dx,ls,rs) { \
     if (sx != dx) { \
@@ -37,11 +37,11 @@
 }
 
 void
-IcBlt (pixman_bits_t   *srcLine,
+IcBlt (FbBits   *srcLine,
        IcStride	srcStride,
        int	srcX,
        
-       pixman_bits_t   *dstLine,
+       FbBits   *dstLine,
        IcStride dstStride,
        int	dstX,
        
@@ -49,16 +49,16 @@
        int	height,
        
        int	alu,
-       pixman_bits_t	pm,
+       FbBits	pm,
        int	bpp,
        
        int	reverse,
        int	upsidedown)
 {
-    pixman_bits_t  *src, *dst;
+    FbBits  *src, *dst;
     int	    leftShift, rightShift;
-    pixman_bits_t  startmask, endmask;
-    pixman_bits_t  bits, bits1;
+    FbBits  startmask, endmask;
+    FbBits  bits, bits1;
     int	    n, nmiddle;
     int    destInvarient;
     int	    startbyte, endbyte;
@@ -72,8 +72,8 @@
     {
 		uint8_t *isrc=(uint8_t *)srcLine;
 		uint8_t *idst=(uint8_t *)dstLine;
-		int sstride=srcStride*sizeof(pixman_bits_t);
-		int dstride=dstStride*sizeof(pixman_bits_t);
+		int sstride=srcStride*sizeof(FbBits);
+		int dstride=dstStride*sizeof(FbBits);
 		int j;
 		width>>=3;
 		isrc+=(srcX>>3);
@@ -178,7 +178,7 @@
 		     */
 		    if (_ca2 + 1 == 0 && _cx2 == 0)
 		    {
-			pixman_bits_t	t1, t2, t3, t4;
+			FbBits	t1, t2, t3, t4;
 			while (n >= 4)
 			{
 			    t1 = *src++;
@@ -350,32 +350,32 @@
 #endif
 
 static void
-IcBlt24Line (pixman_bits_t	    *src,
+IcBlt24Line (FbBits	    *src,
 	     int	    srcX,
 
-	     pixman_bits_t	    *dst,
+	     FbBits	    *dst,
 	     int	    dstX,
 
 	     int	    width,
 
 	     int	    alu,
-	     pixman_bits_t	    pm,
+	     FbBits	    pm,
 	 
 	     int	    reverse)
 {
 #ifdef DEBUG_BLT24
     char    *origDst = (char *) dst;
-    pixman_bits_t  *origLine = dst + ((dstX >> IC_SHIFT) - 1);
+    FbBits  *origLine = dst + ((dstX >> IC_SHIFT) - 1);
     int	    origNlw = ((width + IC_MASK) >> IC_SHIFT) + 3;
     int	    origX = dstX / 24;
 #endif
     
     int	    leftShift, rightShift;
-    pixman_bits_t  startmask, endmask;
+    FbBits  startmask, endmask;
     int	    n;
     
-    pixman_bits_t  bits, bits1;
-    pixman_bits_t  mask;
+    FbBits  bits, bits1;
+    FbBits  mask;
 
     int	    rot;
     IcDeclareMergeRop ();
@@ -564,11 +564,11 @@
 }
 
 void
-IcBlt24 (pixman_bits_t	    *srcLine,
+IcBlt24 (FbBits	    *srcLine,
 	 IcStride   srcStride,
 	 int	    srcX,
 
-	 pixman_bits_t	    *dstLine,
+	 FbBits	    *dstLine,
 	 IcStride   dstStride,
 	 int	    dstX,
 
@@ -576,7 +576,7 @@
 	 int	    height,
 
 	 int	    alu,
-	 pixman_bits_t	    pm,
+	 FbBits	    pm,
 
 	 int	    reverse,
 	 int	    upsidedown)
@@ -608,13 +608,13 @@
  */
 
 void
-IcBltOdd (pixman_bits_t    *srcLine,
+IcBltOdd (FbBits    *srcLine,
 	  IcStride  srcStrideEven,
 	  IcStride  srcStrideOdd,
 	  int	    srcXEven,
 	  int	    srcXOdd,
 
-	  pixman_bits_t    *dstLine,
+	  FbBits    *dstLine,
 	  IcStride  dstStrideEven,
 	  IcStride  dstStrideOdd,
 	  int	    dstXEven,
@@ -624,26 +624,26 @@
 	  int	    height,
 
 	  int	    alu,
-	  pixman_bits_t    pm,
+	  FbBits    pm,
 	  int	    bpp)
 {
-    pixman_bits_t  *src;
+    FbBits  *src;
     int	    leftShiftEven, rightShiftEven;
-    pixman_bits_t  startmaskEven, endmaskEven;
+    FbBits  startmaskEven, endmaskEven;
     int	    nmiddleEven;
     
-    pixman_bits_t  *dst;
+    FbBits  *dst;
     int	    leftShiftOdd, rightShiftOdd;
-    pixman_bits_t  startmaskOdd, endmaskOdd;
+    FbBits  startmaskOdd, endmaskOdd;
     int	    nmiddleOdd;
 
     int	    leftShift, rightShift;
-    pixman_bits_t  startmask, endmask;
+    FbBits  startmask, endmask;
     int	    nmiddle;
     
     int	    srcX, dstX;
     
-    pixman_bits_t  bits, bits1;
+    FbBits  bits, bits1;
     int	    n;
     
     int    destInvarient;
@@ -781,13 +781,13 @@
 
 #ifdef IC_24BIT
 void
-IcBltOdd24 (pixman_bits_t	*srcLine,
+IcBltOdd24 (FbBits	*srcLine,
 	    IcStride	srcStrideEven,
 	    IcStride	srcStrideOdd,
 	    int		srcXEven,
 	    int		srcXOdd,
 
-	    pixman_bits_t	*dstLine,
+	    FbBits	*dstLine,
 	    IcStride	dstStrideEven,
 	    IcStride	dstStrideOdd,
 	    int		dstXEven,
@@ -797,7 +797,7 @@
 	    int		height,
 
 	    int		alu,
-	    pixman_bits_t	pm)
+	    FbBits	pm)
 {
     int    even = 1;
     
@@ -833,7 +833,7 @@
 IcSetBltOdd (IcStip	*stip,
 	     IcStride	stipStride,
 	     int	srcX,
-	     pixman_bits_t	**bits,
+	     FbBits	**bits,
 	     IcStride	*strideEven,
 	     IcStride	*strideOdd,
 	     int	*srcXEven,
@@ -851,7 +851,7 @@
      */
     strideAdjust = stipStride & (IC_MASK >> IC_STIP_SHIFT);
 
-    *bits = (pixman_bits_t *) ((char *) stip - srcAdjust);
+    *bits = (FbBits *) ((char *) stip - srcAdjust);
     if (srcAdjust)
     {
 	*strideEven = IcStipStrideToBitsStride (stipStride + 1);
@@ -873,18 +873,18 @@
 
 void
 IcBltStip (IcStip   *src,
-	   IcStride srcStride,	    /* in IcStip units, not pixman_bits_t units */
+	   IcStride srcStride,	    /* in IcStip units, not FbBits units */
 	   int	    srcX,
 	   
 	   IcStip   *dst,
-	   IcStride dstStride,	    /* in IcStip units, not pixman_bits_t units */
+	   IcStride dstStride,	    /* in IcStip units, not FbBits units */
 	   int	    dstX,
 
 	   int	    width, 
 	   int	    height,
 
 	   int	    alu,
-	   pixman_bits_t   pm,
+	   FbBits   pm,
 	   int	    bpp)
 {
 #if IC_STIP_SHIFT != IC_SHIFT
@@ -895,7 +895,7 @@
 	IcStride    dstStrideEven, dstStrideOdd;
 	int	    srcXEven, srcXOdd;
 	int	    dstXEven, dstXOdd;
-	pixman_bits_t	    *s, *d;
+	FbBits	    *s, *d;
 	int	    sx, dx;
 	
 	src += srcX >> IC_STIP_SHIFT;
@@ -939,9 +939,9 @@
     else
 #endif
     {
-	IcBlt ((pixman_bits_t *) src, IcStipStrideToBitsStride (srcStride), 
+	IcBlt ((FbBits *) src, IcStipStrideToBitsStride (srcStride), 
 	       srcX, 
-	       (pixman_bits_t *) dst, IcStipStrideToBitsStride (dstStride), 
+	       (FbBits *) dst, IcStipStrideToBitsStride (dstStride), 
 	       dstX, 
 	       width, height,
 	       alu, pm, bpp, 0, 0);

Index: icbltone.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icbltone.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- icbltone.c	2 Mar 2005 15:43:33 -0000	1.7
+++ icbltone.c	24 Jun 2005 02:35:45 -0000	1.8
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 /*
  *  Example: srcX = 13 dstX = 8	(IC unit 32 dstBpp 8)
@@ -138,27 +138,27 @@
 IcBltOne (IcStip    *src,
 	  IcStride  srcStride,	    /* IcStip units per scanline */
 	  int	    srcX,	    /* bit position of source */
-	  pixman_bits_t    *dst,
-	  IcStride  dstStride,	    /* pixman_bits_t units per scanline */
+	  FbBits    *dst,
+	  IcStride  dstStride,	    /* FbBits units per scanline */
 	  int	    dstX,	    /* bit position of dest */
 	  int	    dstBpp,	    /* bits per destination unit */
 
 	  int	    width,	    /* width in bits of destination */
 	  int	    height,	    /* height in scanlines */
 
-	  pixman_bits_t    fgand,	    /* rrop values */
-	  pixman_bits_t    fgxor,
-	  pixman_bits_t    bgand,
-	  pixman_bits_t    bgxor)
+	  FbBits    fgand,	    /* rrop values */
+	  FbBits    fgxor,
+	  FbBits    bgand,
+	  FbBits    bgxor)
 {
-    const pixman_bits_t    *icbits;
-    int		    pixelsPerDst;		/* dst pixels per pixman_bits_t */
+    const FbBits    *icbits;
+    int		    pixelsPerDst;		/* dst pixels per FbBits */
     int		    unitsPerSrc;		/* src patterns per IcStip */
     int		    leftShift, rightShift;	/* align source with dest */
-    pixman_bits_t	    startmask, endmask;		/* dest scanline masks */
+    FbBits	    startmask, endmask;		/* dest scanline masks */
     IcStip	    bits=0, bitsLeft, bitsRight;/* source bits */
     IcStip	    left;
-    pixman_bits_t	    mask;
+    FbBits	    mask;
     int		    nDst;			/* dest longwords (w.o. end) */
     int		    w;
     int		    n, nmiddle;
@@ -184,7 +184,7 @@
 #endif
     
     /*
      * Number of destination units in pixman_bits_t == number of stipple pixels
      * used each time
      */
     pixelsPerDst = IC_UNIT / dstBpp;
@@ -202,7 +202,7 @@
 	transparent = 1;
 
     /*
      * Adjust source and dest to nearest pixman_bits_t boundary
      */
     src += srcX >> IC_STIP_SHIFT;
     dst += dstX >> IC_SHIFT;
@@ -455,7 +455,7 @@
 #define IcStip24New(rot)    (2 + (rot != 0))
 #define IcStip24Len	    4
 
-static const pixman_bits_t icStipple24Bits[3][1 << IcStip24Len] = {
+static const FbBits icStipple24Bits[3][1 << IcStip24Len] = {
     /* rotate 0 */
     {
 	C4_24( 0, 0), C4_24( 1, 0), C4_24( 2, 0), C4_24( 3, 0),
@@ -493,7 +493,7 @@
 #define IcStip24New(rot)    (1 + (rot == 8))
 #endif
 
-static const pixman_bits_t icStipple24Bits[3][1 << IcStip24Len] = {
+static const FbBits icStipple24Bits[3][1 << IcStip24Len] = {
     /* rotate 0 */
     {
 	C2_24( 0, 0), C2_24 ( 1, 0), C2_24 ( 2, 0), C2_24 ( 3, 0),
@@ -571,21 +571,21 @@
 IcBltOne24 (IcStip	*srcLine,
 	    IcStride	srcStride,  /* IcStip units per scanline */
 	    int		srcX,	    /* bit position of source */
-	    pixman_bits_t	*dst,
-	    IcStride	dstStride,  /* pixman_bits_t units per scanline */
+	    FbBits	*dst,
+	    IcStride	dstStride,  /* FbBits units per scanline */
 	    int		dstX,	    /* bit position of dest */
 	    int		dstBpp,	    /* bits per destination unit */
 
 	    int		width,	    /* width in bits of destination */
 	    int		height,	    /* height in scanlines */
 
-	    pixman_bits_t	fgand,	    /* rrop values */
-	    pixman_bits_t	fgxor,
-	    pixman_bits_t	bgand,
-	    pixman_bits_t	bgxor)
+	    FbBits	fgand,	    /* rrop values */
+	    FbBits	fgxor,
+	    FbBits	bgand,
+	    FbBits	bgxor)
 {
     IcStip	*src;
-    pixman_bits_t	leftMask, rightMask, mask;
+    FbBits	leftMask, rightMask, mask;
     int		nlMiddle, nl;
     IcStip	stip, bits;
     int		remain;
@@ -184,7 +184,7 @@
     
     /*
-     * Number of destination units in pixman_bits_t == number of stipple pixels
+     * Number of destination units in FbBits == number of stipple pixels
      * used each time
      */
@@ -202,7 +202,7 @@
 
     /*
-     * Adjust source and dest to nearest pixman_bits_t boundary
+     * Adjust source and dest to nearest FbBits boundary
      */
     src += srcX >> IC_STIP_SHIFT;
